# Generated by Django 3.1.6 on 2021-03-01 10:40

from django.db import migrations

import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0072_userview'),
    ]

    operations = [
        migrations.AlterField(
            model_name='standard_colors',
            name='color',
            field=isc_common.fields.code_field.ColorField(blank=True, null=True),
        ),
    ]
