# Generated by Django 2.2.5 on 2019-09-05 18:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0059_auto_20190905_0519'),
        ('twits', '0008_chat_user_user_theme'),
    ]

    operations = [
        migrations.RenameField(
            model_name='chat_user_user_theme',
            old_name='messages_theme',
            new_name='theme',
        ),
        migrations.AlterUniqueTogether(
            name='chat_user_user_theme',
            unique_together={('chat_user_user', 'theme')},
        ),
    ]
