# Generated by Django 3.1.6 on 2021-02-19 06:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0066_auditmodelex'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='auditmodelex',
            name='edited_by',
        ),
    ]
