# Generated by Django 2.2.4 on 2019-08-25 11:03

from django.db import migrations
import isc_common.fields.date_time_field
import isc_common.fields.time_field


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0063_auto_20190825_1024'),
    ]

    operations = [
        migrations.AlterField(
            model_name='calendars',
            name='begindate',
            field=isc_common.fields.date_time_field.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Начало'),
        ),
        migrations.AlterField(
            model_name='calendars',
            name='enddate',
            field=isc_common.fields.date_time_field.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Конец'),
        ),
        migrations.AlterField(
            model_name='holidays',
            name='begindate',
            field=isc_common.fields.date_time_field.DateTimeField(db_index=True, verbose_name='Начало'),
        ),
        migrations.AlterField(
            model_name='holidays',
            name='enddate',
            field=isc_common.fields.date_time_field.DateTimeField(db_index=True, verbose_name='Конец'),
        ),
        migrations.AlterField(
            model_name='shift_day',
            name='begintime',
            field=isc_common.fields.time_field.TimeField(db_index=True, verbose_name='Начало'),
        ),
        migrations.AlterField(
            model_name='shift_day',
            name='endtime',
            field=isc_common.fields.time_field.TimeField(db_index=True, verbose_name='Конец'),
        ),
        migrations.AlterField(
            model_name='shift_day_relax',
            name='begintime',
            field=isc_common.fields.time_field.TimeField(db_index=True, verbose_name='Начало периода'),
        ),
        migrations.AlterField(
            model_name='shift_day_relax',
            name='endtime',
            field=isc_common.fields.time_field.TimeField(db_index=True, verbose_name='Конец периода'),
        ),
    ]
