# Generated by Django 2.2.3 on 2019-07-06 10:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0010_auto_20190629_2304'),
    ]

    operations = [
        migrations.AddField(
            model_name='documents_param_1c',
            name='value_uuid',
            field=models.UUIDField(blank=True, db_index=True, null=True),
        ),
        migrations.AlterField(
            model_name='documents_param_1c',
            name='value',
            field=models.TextField(blank=True, db_index=True, null=True),
        ),
    ]
