# Generated by Django 2.2.2 on 2019-06-29 23:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0009_auto_20190616_0450'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='documents_param_cross_1c',
            unique_together={('document', 'param')},
        ),
    ]
