# Generated by Django 3.2.6 on 2021-08-10 15:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('react', '0014_pages_type'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='fragment_params',
            name='type',
        ),
        migrations.DeleteModel(
            name='Fragment_param_types',
        ),
    ]
