# Generated by Django 3.1.7 on 2021-03-26 09:48

from django.db import migrations

import isc_common.fields.code_field


class Migration(migrations.Migration):
    dependencies = [
        ('twits', '0019_auto_20190919_1620'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chats',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(),
        ),
    ]
