# Generated by Django 3.2.6 on 2021-08-24 21:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0120_alter_image_types_unique_together'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Users_old_images',
        ),
    ]
