# Generated by Django 3.1.7 on 2021-03-10 00:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0078_auto_20210309_0919'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='attfile',
        ),
        migrations.RemoveField(
            model_name='user',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='user',
            name='deliting',
        ),
        migrations.RemoveField(
            model_name='user',
            name='editing',
        ),
        migrations.RemoveField(
            model_name='user',
            name='file_store',
        ),
        migrations.RemoveField(
            model_name='user',
            name='format',
        ),
        migrations.RemoveField(
            model_name='user',
            name='key',
        ),
        migrations.RemoveField(
            model_name='user',
            name='lastmodified',
        ),
        migrations.RemoveField(
            model_name='user',
            name='mime_type',
        ),
        migrations.RemoveField(
            model_name='user',
            name='real_name',
        ),
        migrations.RemoveField(
            model_name='user',
            name='size',
        ),
        migrations.AlterField(
            model_name='user',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
