# Generated by Django 3.1.7 on 2021-04-06 10:32

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0091_delete_auditmodelex'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='users_images',
            name='Users_images_unique_constraint_2',
        ),
        migrations.RemoveConstraint(
            model_name='users_images',
            name='Users_images_unique_constraint_3',
        ),
    ]
