# Generated by Django 3.2.7 on 2021-09-13 10:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0131_text_informations_props'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='images',
            unique_together={('file_name', 'size'), ('real_name', 'size')},
        ),
    ]
