# Generated by Django 2.2.6 on 2019-10-12 09:15

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0069_messages_importance'),
    ]

    operations = [
        migrations.AddField(
            model_name='messages',
            name='importance',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='tracker.Messages_importance'),
        ),
    ]
