# Generated by Django 3.2.3 on 2021-05-14 15:27

from django.db import migrations
import isc_common.fields.files


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0089_alter_messages_files_real_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages_files',
            name='attfile',
            field=isc_common.fields.files.FileFieldEx(default=None, max_length=255, upload_to='', verbose_name='Файл'),
            preserve_default=False,
        ),
    ]
