# Generated by Django 3.2.6 on 2021-08-31 22:39
import django
from django.db import migrations

import isc_common


class Migration( migrations.Migration ) :
    dependencies = [
        ('isc_common' , '0125_image_types_c_event') ,
        ('competitions', '0360_auto_20210831_2135'),
    ]

    operations = [
        migrations.AlterField(
            model_name='users_images' ,
            name='type' ,
            field=isc_common.fields.related.ForeignKeyProtect( default=None , on_delete=django.db.models.deletion.PROTECT , to='isc_common.image_types' ) ,
            preserve_default=False ,
        ) ,
    ]
