# Generated by Django 2.2 on 2019-04-21 15:01

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0016_messages_view'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='user',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, related_name='user', to=settings.AUTH_USER_MODEL),
        ),
    ]
