# Generated by Django 3.1.7 on 2021-03-23 05:53

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0087_auto_20210316_0827'),
    ]

    operations = [
        migrations.RenameField(
            model_name='user',
            old_name='birtdate',
            new_name='birthday',
        ),
    ]
