# Generated by Django 3.2.6 on 2021-08-23 07:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0106_auto_20210823_0721'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='users_images',
            unique_together={('image', 'main_model', 'props', 'type', 'deleted_at')},
        ),
    ]
