# Generated by Django 2.2.4 on 2019-08-24 19:24

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0050_auto_20190824_1921'),
    ]

    operations = [
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='friday',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='friday_rel', to='clndr.Shift_day'),
        ),
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='monday',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='monday_rel', to='clndr.Shift_day'),
        ),
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='saturday',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='saturday_rel', to='clndr.Shift_day'),
        ),
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='sunday',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='sunday_rel', to='clndr.Shift_day'),
        ),
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='thursday',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='thursday_rel', to='clndr.Shift_day'),
        ),
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='tuesday',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='tuesday_rel', to='clndr.Shift_day'),
        ),
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='wednesday',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='wednesday_rel', to='clndr.Shift_day'),
        ),
    ]
