# Generated by Django 3.1.6 on 2021-02-11 07:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0082_auto_20210211_0715'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='message',
            field=models.TextField(),
        ),
    ]
