# Generated by Django 2.2.4 on 2019-08-21 16:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0015_day_types'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='holidays',
            name='props',
        ),
    ]
