# Generated by Django 3.0.2 on 2020-01-22 07:38

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0033_standard_colors'),
    ]

    operations = [
        migrations.AddField(
            model_name='standard_colors',
            name='color',
            field=isc_common.fields.code_field.ColorField(),
        ),
    ]
