# Generated by Django 3.2.6 on 2021-08-11 17:36

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('react', '0020_pages_props'),
    ]

    operations = [
        migrations.AddField(
            model_name='fragment_params',
            name='props',
            field=bitfield.models.BitField((('use_generator', 'Используется генератором'),), db_index=True, default=0),
        ),
        migrations.AlterField(
            model_name='pages',
            name='props',
            field=bitfield.models.BitField((('application', 'Приложение'),), db_index=True, default=0),
        ),
    ]
