# Generated by Django 3.2.6 on 2021-08-23 12:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0112_auto_20210823_1246'),
    ]

    operations = [

    ]
