# Generated by Django 2.2.5 on 2019-09-03 21:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0047_auto_20190903_2126'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='messages',
            name='checksum',
        ),
    ]
