# Generated by Django 2.1.7 on 2019-02-16 23:17

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0005_usergroup_permission'),
    ]

    operations = [
        migrations.AlterField(
            model_name='widgets_trees',
            name='id_widget',
            field=isc_common.fields.code_field.CodeField(unique=True),
        ),
    ]
