# Generated by Django 3.2.6 on 2021-08-22 16:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0104_alter_images_unique_together'),
    ]

    operations = [
        migrations.AlterField(
            model_name='images',
            name='real_name',
            field=models.TextField(db_index=True, verbose_name='Первоначальное имя файла'),
        ),
    ]
