# Generated by Django 3.2.6 on 2021-08-22 15:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0103_users_old_images'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='images',
            unique_together={('real_name', 'size', 'image_type')},
        ),
    ]
