# Generated by Django 3.1.6 on 2021-03-01 06:10

import django.db.models.deletion
from django.db import migrations, models

import isc_common.auth.managers.user_manager


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0071_delete_auditmodelwitholdid'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserView',
            fields=[
                ('user_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='isc_common.user')),
            ],
            options={
                'verbose_name': 'Пользователь',
                'db_table': 'isc_common_user_view',
                'managed': False,
            },
            bases=('isc_common.user',),
            managers=[
                ('objects', isc_common.auth.managers.user_manager.UserManager()),
            ],
        ),
    ]
