# Generated by Django 3.1.6 on 2021-03-02 16:59

from django.db import migrations

import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0074_auto_20210301_1105'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='e_mails',
            name='phone',
        ),
        migrations.AddField(
            model_name='e_mails',
            name='e_mail',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
        migrations.AlterField(
            model_name='phones',
            name='phone',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
    ]
