# Generated by Django 3.2.6 on 2021-09-01 06:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0126_auto_20210831_2239'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='images',
            name='image_type',
        ),
    ]
