# Generated by Django 2.2.4 on 2019-08-22 22:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0024_auto_20190822_1100'),
    ]

    operations = [
        migrations.AddField(
            model_name='shift_day',
            name='dinnertime',
            field=models.TimeField(blank=True, db_index=True, null=True, verbose_name='Конец'),
        ),
    ]
