# Generated by Django 3.1.5 on 2021-01-21 06:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0056_last_used_processes'),
    ]

    operations = [
        migrations.CreateModel(
            name='Debug',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField()),
            ],
            options={
                'verbose_name': 'Отладочная информация',
            },
        ),
    ]
