# Generated by Django 3.1.7 on 2021-03-04 14:35

import django.db.models.deletion
from django.conf import settings
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0075_auto_20210302_1659'),
    ]

    operations = [
        migrations.AddField(
            model_name='auditmodelex',
            name='updator',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='AuditModelEx_updator', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='auditmodelex',
            name='creator',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='AuditModelEx_creator', to=settings.AUTH_USER_MODEL),
        ),
    ]
