# Generated by Django 3.2.5 on 2021-07-27 16:31

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0102_alter_images_size'),
        ('react', '0006_auto_20210726_2125'),
    ]

    operations = [
        migrations.AddField(
            model_name='fragment_params',
            name='image',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='isc_common.images'),
        ),
        migrations.AddField(
            model_name='fragment_params',
            name='value_dec',
            field=models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True),
        ),
        migrations.AddField(
            model_name='fragment_params',
            name='value_text',
            field=models.TextField(blank=True, null=True),
        ),
    ]
