# Generated by Django 3.2.6 on 2021-08-23 12:38

from django.db import migrations , transaction , connection

from isc_common.models.images import Images
from lfl_admin.common.models.all_tables import All_tables


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0110_alter_images_unique_together'),
    ]

    operations = [
    ]
