# Generated by Django 2.2.2 on 2019-06-10 15:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0005_auto_20190610_1530'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='documents_param_1c',
            unique_together=set(),
        ),
    ]
