# Generated by Django 2.2.4 on 2019-08-25 10:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0061_auto_20190825_1019'),
    ]

    operations = [
        migrations.AlterField(
            model_name='calendar_shifts_days',
            name='shiftorder',
            field=models.PositiveIntegerField(),
        ),
    ]
