# Generated by Django 3.2.6 on 2021-08-23 12:46

from django.db import migrations , transaction
from tqdm import tqdm

from isc_common.common import unknown
from lfl_admin.competitions.models.disqualification_condition import Disqualification_condition
from lfl_admin.competitions.models.disqualification_zones import Disqualification_zones
from lfl_admin.competitions.models.division_stages import Division_stages
from lfl_admin.competitions.models.divisions import Divisions
from lfl_admin.competitions.models.tournaments import Tournaments
from lfl_admin.region.models.regions import Regions


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0111_auto_20210823_1238'),
    ]

    operations = [

    ]
