# Generated by Django 3.2.4 on 2021-07-26 21:25

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.code_field
import isc_common.fields.description_field
import isc_common.fields.name_field
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('react', '0005_alter_fragments_item_types_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='fragment_param_types',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
        migrations.AddField(
            model_name='fragment_param_types',
            name='description',
            field=isc_common.fields.description_field.DescriptionField(),
        ),
        migrations.AddField(
            model_name='fragment_param_types',
            name='name',
            field=isc_common.fields.name_field.NameField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='fragment_params',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
        migrations.AddField(
            model_name='fragment_params',
            name='description',
            field=isc_common.fields.description_field.DescriptionField(),
        ),
        migrations.AddField(
            model_name='fragment_params',
            name='name',
            field=isc_common.fields.name_field.NameField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='fragments',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='react.fragments'),
        ),
        migrations.AddField(
            model_name='fragments_item_types',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
        migrations.AddField(
            model_name='fragments_item_types',
            name='description',
            field=isc_common.fields.description_field.DescriptionField(),
        ),
        migrations.AddField(
            model_name='fragments_item_types',
            name='name',
            field=isc_common.fields.name_field.NameField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='fragments',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(),
        ),
    ]
